@@ -21,6 +21,12 @@ from aqueduct.error import (
 from aqueduct.flow import Flow
 from aqueduct.github import Github
 from aqueduct.integrations.airflow_integration import AirflowIntegration
+from aqueduct.integrations.connect_config import (
+    BaseConnectionConfig,
+    IntegrationConfig,
+    convert_dict_to_integration_connect_config,
+)
+from aqueduct.integrations.databricks_integration import DatabricksIntegration
 from aqueduct.integrations.google_sheets_integration import GoogleSheetsIntegration
 from aqueduct.integrations.k8s_integration import K8sIntegration
 from aqueduct.integrations.lambda_integration import LambdaIntegration
@@ -43,9 +49,9 @@ from aqueduct.utils.type_inference import infer_artifact_type
 from aqueduct.utils.utils import (
     construct_param_spec,
     generate_engine_config,
+    generate_flow_schedule,
     generate_ui_url,
     parse_user_supplied_id,
-    schedule_from_cron_string,
 )
 
 from aqueduct import globals
@@ -188,6 +194,45 @@ class Client:
         """
         return create_param_artifact(self._dag, name, default, description)
 
+    def connect_integration(
+        self, name: str, service: ServiceType, config: Union[Dict[str, str], IntegrationConfig]
+    ) -> None:
+        """Connects the Aqueduct server to an integration.
+
+        Args:
+            name:
+                The name to assign this integration. Will error if an integration with that name
+                already exists.
+            service:
+                The type of integration to connect to.
+            config:
+                Either a dictionary or an IntegrationConnectConfig object that contains the
+                configuration credentials needed to connect.
+        """
+        if service not in ServiceType:
+            raise InvalidUserArgumentException(
+                "Service argument must match exactly one of the enum values in ServiceType (case-sensitive)."
+            )
+
+        self._connected_integrations = globals.__GLOBAL_API_CLIENT__.list_integrations()
+        if name in self._connected_integrations.keys():
+            raise InvalidUserActionException(
+                "Cannot connect a new integration with name `%s`. An integration with this name already exists."
+                % name
+            )
+
+        if not isinstance(config, dict) and not isinstance(config, BaseConnectionConfig):
+            raise InvalidUserArgumentException(
+                "`config` argument must be either a dict or IntegrationConnectConfig."
+            )
+
+        if isinstance(config, dict):
+            config = convert_dict_to_integration_connect_config(service, config)
+        assert isinstance(config, BaseConnectionConfig)
+
+        globals.__GLOBAL_API_CLIENT__.connect_integration(name, service, config)
+        logger().info("Successfully connected to new %s integration `%s`." % (service, name))
+
     def list_integrations(self) -> Dict[str, IntegrationInfo]:
         """Retrieves a dictionary of integrations the client can use.
 
@@ -208,6 +253,7 @@ class Client:
         K8sIntegration,
         LambdaIntegration,
         MongoDBIntegration,
+        DatabricksIntegration,
     ]:
         """Retrieves a connected integration object.
 
@@ -267,6 +313,10 @@ class Client:
                 dag=self._dag,
                 metadata=integration_info,
             )
+        elif integration_info.service == ServiceType.DATABRICKS:
+            return DatabricksIntegration(
+                metadata=integration_info,
+            )
         else:
             raise InvalidIntegrationException(
                 "This method does not support loading integration of type %s"
@@ -321,6 +371,7 @@ class Client:
         checks: Optional[List[BoolArtifact]] = None,
         k_latest_runs: Optional[int] = None,
         config: Optional[FlowConfig] = None,
+        source_flow: Optional[Union[Flow, str, uuid.UUID]] = None,
     ) -> Flow:
         """Uploads and kicks off the given flow in the system.
 
@@ -369,6 +420,9 @@ class Client:
                 - engine: Specify where this flow should run with one of your connected integrations.
                 - k_latest_runs: Number of most-recent runs of this flow that Aqueduct should store.
                     Runs outside of this bound are deleted. Defaults to persisting all runs.
+            source_flow:
+                Used to identify the source flow for this flow. This can be identified
+                via an object (Flow), name (str), or id (str or uuid).
 
         Raises:
             InvalidUserArgumentException:
@@ -416,6 +470,38 @@ class Client:
                 "`artifacts` argument must either be an artifact or a list of artifacts."
             )
 
+        if source_flow and schedule != "":
+            raise InvalidUserArgumentException(
+                "Cannot create a flow with both a schedule and a source flow, pick one."
+            )
+
+        if (
+            source_flow
+            and not isinstance(source_flow, Flow)
+            and not isinstance(source_flow, str)
+            and not isinstance(source_flow, uuid.UUID)
+        ):
+            raise InvalidUserArgumentException(
+                "`source_flow` argument must either be a flow, str, or uuid."
+            )
+
+        source_flow_id = None
+        if isinstance(source_flow, Flow):
+            source_flow_id = source_flow.id()
+        elif isinstance(source_flow, str):
+            # Check if there is a flow with the name `source_flow`
+            for workflow in globals.__GLOBAL_API_CLIENT__.list_workflows():
+                if workflow.name == source_flow:
+                    source_flow_id = workflow.id
+                    break
+
+            if not source_flow_id:
+                # No flow with name `source_flow` was found so try to convert
+                # the str to a uuid
+                source_flow_id = uuid.UUID(source_flow)
+        elif isinstance(source_flow, uuid.UUID):
+            source_flow_id = source_flow
+
         # If metrics and/or checks are explicitly included, add them to the artifacts list,
         # but don't include them implicitly.
         implicitly_include_metrics = True
@@ -432,7 +518,7 @@ class Client:
             artifacts += checks
             implicitly_include_checks = False
 
-        cron_schedule = schedule_from_cron_string(schedule)
+        flow_schedule = generate_flow_schedule(schedule, source_flow_id)
 
         k_latest_runs_from_flow_config = config.k_latest_runs if config else None
         if k_latest_runs and k_latest_runs_from_flow_config:
@@ -466,7 +552,7 @@ class Client:
         dag.metadata = Metadata(
             name=name,
             description=description,
-            schedule=cron_schedule,
+            schedule=flow_schedule,
             retention_policy=retention_policy,
         )
         dag.set_engine_config(
